#! /bin/sh
#----------------------------------------------------------------
#Procedure to return the keyboard layout selected
#by user.
#choice is done among the available keyboard map.
#----------------------------------------------------------------
FCONSOLE=/etc/sysconfig/console
FLANG=/etc/profile.d/lang.sh
#----------------------------------------------------------------
TMPNAME=/tmp/`basename $0`-$$
KEYDIR=/usr/share/keymaps

#setting the terminal TYPE
TERM=linux
#----------------------------------------------------------------
#extracting known keyboard
for layout in `find $KEYDIR -name *.map.gz -exec sh -c "basename -a -s .map.gz {}" \; -print | sort -u`
  do
  #layout=`basename -a -s .map.gz $kfile`
  country=""
  case "$layout" in
    "cf"	)  country="Francais-Quebec"	;;
    "de"	)  country="Deutsche"		;;
    "fr-latin9"	)  country="Francais"		;;
    "it"	)  country="Italiana"		;;
    "us"	)  country="USA"		;;
    "*"		)				;;
    esac
  if [ -n "$country" ] ; then
    echo "\"$layout\" \"($country)\""
    fi
  done | tr '\n' ' ' > $TMPNAME
#----------------------------------------------------------
#selecting the keyboard entry
exec 3>&1;
result=$(dialog										\
	--aspect 10									\
	--default-item "us"								\
	--no-cancel									\
	--menu "   Select the Keyboard layout\n(UP/DOWN arrows then ENTER key)" 0 40 0	\
	--file $TMPNAME									\
	2>&1 1>&3);

exec 3>&-;
if [ $? != 0 ] ; then
  exit 1		#trouble trouble
  fi
#----------------------------------------------------------
#adjusting current keyboard and setting console parameters
loadkeys $result > /dev/null 2>&1
if [ -w $FCONSOLE ] ; then
  (
  echo "#----------------------------------------------"
  echo "#Entries added by `basename $0`"
  echo "#KEYMAP variable"
  echo "KEYMAP=$result"
  echo "#----------------------------------------------"
  ) >> $FCONSOLE
  fi

#setting Language
case "$result" in
    "cf"	)  map="UTF-8" ; cnt="fr_CA"	;;
    "fr-latin9"	)  map="UTF-8" ; cnt="fr_FR"	;;
    "us"	)  map="UTF-8" ; cnt="en_US"	;;
    "de"	|				\
    "it"	|				\
    "*"		)				;;
    esac
if [ -n "$map" ] ; then
  clear
  echo "Setting system LANG to \"$cnt\""
  (
  echo "#----------------------------------------------"
  echo "#Entries added by `basename $0`"
  echo "#LANG variable"
  echo "export LANG=$cnt.$map"
  echo "#----------------------------------------------"
  ) >> $FLANG
  fi

#----------------------------------------------------------
#removing intermediate file and exiting
rm -fr $TMPNAME
exit 0
 
